cluster_est_Mbinder_norm(c, Mu, Sigma, lambda = 0, a = 1, b = a, logposterior)n. c[[j]][i] is
the cluster allocation of observation i=1...n at iteration
j=1...N.n composed of p x l matrices.
Where l is the maximum number of components per partition.n composed of arrays containing a maximum of
l p x p covariance matrices.c used to break ties when minimizing the cost functionlist:
c_est: a vector of length n. Point estimate of the partition
cost: a vector of length N. cost[j] is the cost
associated to partition c[[j]]
similarity: matrix of size n x n. Similarity matrix
(see similarityMat)
opt_ind: the index of the optimal partition
among the MCMC iterations.
The modified Binder loss function takes into account the distance between mixture components using #'the Bhattacharyya distance.
DA Binder, Bayesian cluster analysis, Biometrika 65(1):31-38, 1978.
similarityMat similarityMatC
similarityMat_nocostC