Learn R Programming

NPflow (version 0.9.0)

Fmeasure_costC: Multiple cost computations with Fmeasure as the loss function

Description

C++ implementation of multiple cost computations with Fmeasure as the loss function using the Armadillo library

Usage

Fmeasure_costC(c)

Arguments

c
a matrix where each column is one MCMC partition

Value

  • a list with the following elements:
    • Fmeas
    {TODO}

Examples

Run this code
library(NPflow)
c <- list(c(1,1,2,3,2,3), c(1,1,1,2,3,3),c(2,2,1,1,1,1))
#Fmeasure_costC(sapply(c, "["))

c2 <- list()
for(i in 1:100){
    c2 <- c(c2, list(rmultinom(n=1, size=2000, prob=rexp(n=2000))))
}
Fmeasure_costC(sapply(c2, "["))

Run the code above in your browser using DataLab