print.summaryDPMMclust: Methods for a summary of a 'DPMMclust' object
Description
Methods for a summary of a 'DPMMclust' object
Usage
"print"(x, ...)
"plot"(x, hm = FALSE, nbsim_densities = 5000, gg.add = list(theme_bw()), ...)
Arguments
x
a summaryDPMMclust object.
...
further arguments passed to or from other methods
hm
logical flag to plot the heatmap of the similarity matrix.
Default is FALSE.
nbsim_densities
the number of simulated observations to be used
to plot the density lines of the clusters in the point estimate partition plot
gg.add
a list of instructions to add to the ggplot2 instruction.
See +.gg. Default is list(theme()), which adds nothing to the plot.